# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....organization_providers.resources.v_3.types.organization_provider_v_2 import OrganizationProviderV2
from .....payers.resources.v_3.types.payer import Payer
from .credentialing_span_status import CredentialingSpanStatus


class BaseCredentialingSpan(UniversalBaseModel):
    contracting_provider: OrganizationProviderV2 = pydantic.Field()
    """
    The practice location at which the rendering provider is covered by the credentialing span.
    """

    payer: Payer = pydantic.Field()
    """
    The payer doing the credentialing.
    """

    start_date: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    Start date of the credentialing span.
    """

    end_date: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    End date of the credentialing span.
    """

    submitted_date: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    Date that the credential paperwork was submitted.
    """

    credentialing_status: CredentialingSpanStatus = pydantic.Field()
    """
    Status of the credentialing span.
    """

    payer_loaded_date: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    Date that the payer loaded the credentialing span into their system.
    """

    is_enabled: bool = pydantic.Field()
    """
    Is the credentialing span enabled?
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .diagnosis_not_found_http_error import DiagnosisNotFoundHttpError
from .disallow_multiple_primary_diagnosis_http_error import DisallowMultiplePrimaryDiagnosisHttpError
from .service_lines_must_have_at_least_one_diagnosis_http_error import ServiceLinesMustHaveAtLeastOneDiagnosisHttpError

__all__ = [
    "DiagnosisNotFoundHttpError",
    "DisallowMultiplePrimaryDiagnosisHttpError",
    "ServiceLinesMustHaveAtLeastOneDiagnosisHttpError",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import ClearinghousePayerInfo, Payer, PayerIds, PayerPage, PayerUuid, PrimaryPayerIds, SupportState

__all__ = ["ClearinghousePayerInfo", "Payer", "PayerIds", "PayerPage", "PayerUuid", "PrimaryPayerIds", "SupportState"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    UniversalEncounterCreate,
    UniversalEncounterCreateBase,
    UniversalEncounterCreateFromPreEncounter,
    UniversalEncounterCreateFromPreEncounterBase,
    UniversalEncounterUpdate,
    UniversalEncounterUpdateBase,
)

__all__ = [
    "UniversalEncounterCreate",
    "UniversalEncounterCreateBase",
    "UniversalEncounterCreateFromPreEncounter",
    "UniversalEncounterCreateFromPreEncounterBase",
    "UniversalEncounterUpdate",
    "UniversalEncounterUpdateBase",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...non_insurance_payers.resources.v_1.types.non_insurance_payer_id import NonInsurancePayerId
from .patient_clinical_trial_info_create import PatientClinicalTrialInfoCreate


class PatientNonInsurancePayerInfoCreate(UniversalBaseModel):
    non_insurance_payer_id: NonInsurancePayerId
    member_id: typing.Optional[str] = None
    clinical_trial_info: typing.Optional[typing.List[PatientClinicalTrialInfoCreate]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .payer_id import PayerId
from .payer_name import PayerName


class PayerInfo(UniversalBaseModel):
    payer_id: PayerId
    payer_name: PayerName

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.service_line_id import ServiceLineId
from .patient_write_off_reason import PatientWriteOffReason


class PatientWriteOffCreate(UniversalBaseModel):
    write_off_timestamp: dt.datetime
    write_off_note: typing.Optional[str] = None
    write_off_reason: PatientWriteOffReason
    service_line_id: ServiceLineId
    amount_cents: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClinicalTrialPhase(str, enum.Enum):
    PHASE_ONE = "Phase 1"
    PHASE_TWO = "Phase 2"
    PHASE_THREE = "Phase 3"
    _UNKNOWN = "__CLINICALTRIALPHASE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ClinicalTrialPhase":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        phase_one: typing.Callable[[], T_Result],
        phase_two: typing.Callable[[], T_Result],
        phase_three: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ClinicalTrialPhase.PHASE_ONE:
            return phase_one()
        if self is ClinicalTrialPhase.PHASE_TWO:
            return phase_two()
        if self is ClinicalTrialPhase.PHASE_THREE:
            return phase_three()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import InsuranceCard, InsuranceCardBase, InsuranceCardCreate, InsuranceCardCreateOptional, InsuranceCardId

__all__ = [
    "InsuranceCard",
    "InsuranceCardBase",
    "InsuranceCardCreate",
    "InsuranceCardCreateOptional",
    "InsuranceCardId",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.resource_page import ResourcePage
from .organization_provider_v_2 import OrganizationProviderV2


class OrganizationProviderPageV2(ResourcePage):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid.resources.commons import State
    from candid.resources.identifiers import (
        Identifier,
        IdentifierCode,
        IdentifierValue_MedicareProviderIdentifier,
    )
    from candid.resources.organization_providers.resources.v_2 import (
        LicenseType,
        ProviderType,
    )
    from candid.resources.organization_providers.resources.v_3 import (
        OrganizationProviderPageV2,
        OrganizationProviderV2,
    )

    OrganizationProviderPageV2(
        items=[
            OrganizationProviderV2(
                npi="1234567890",
                is_rendering=True,
                is_billing=True,
                first_name="John",
                last_name="Doe",
                organization_name="Acme Medical",
                provider_type=ProviderType.INDIVIDUAL,
                tax_id="123456789",
                taxonomy_code="1234567890",
                license_type=LicenseType.MD,
                employment_start_date=datetime.date.fromisoformat(
                    "2020-10-07",
                ),
                employment_termination_date=datetime.date.fromisoformat(
                    "2021-10-07",
                ),
                organization_provider_id=uuid.UUID(
                    "965a563a-0285-4910-9569-e3739c0f6eab",
                ),
                qualifications=[
                    Identifier(
                        identifier_id=uuid.UUID(
                            "123e4567-e89b-12d3-a456-426614174000",
                        ),
                        identifier_code=IdentifierCode.MCR,
                        identifier_value=IdentifierValue_MedicareProviderIdentifier(
                            state=State.CA,
                            provider_number="1234567890",
                        ),
                    )
                ],
            )
        ],
    )
    """

    items: typing.List[OrganizationProviderV2]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .insurance_adjustment_info import InsuranceAdjustmentInfo
from .insurance_payment_info import InsurancePaymentInfo
from .invalid_filters_error_type import InvalidFiltersErrorType
from .inventory_record import InventoryRecord
from .invoice_itemization_response import InvoiceItemizationResponse
from .list_inventory_paged_response import ListInventoryPagedResponse
from .non_insurance_adjustment_info import NonInsuranceAdjustmentInfo
from .non_insurance_payment_info import NonInsurancePaymentInfo
from .patient_adjustment_info import PatientAdjustmentInfo
from .patient_ar_status import PatientArStatus
from .patient_payment_allocation import PatientPaymentAllocation
from .patient_payment_info import PatientPaymentInfo
from .service_line_itemization import ServiceLineItemization

__all__ = [
    "InsuranceAdjustmentInfo",
    "InsurancePaymentInfo",
    "InvalidFiltersErrorType",
    "InventoryRecord",
    "InvoiceItemizationResponse",
    "ListInventoryPagedResponse",
    "NonInsuranceAdjustmentInfo",
    "NonInsurancePaymentInfo",
    "PatientAdjustmentInfo",
    "PatientArStatus",
    "PatientPaymentAllocation",
    "PatientPaymentInfo",
    "ServiceLineItemization",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OccurrenceInformationCodeQualifier(str, enum.Enum):
    CBH = "BH"
    """
    Occurrence
    """

    _UNKNOWN = "__OCCURRENCEINFORMATIONCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OccurrenceInformationCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(self, cbh: typing.Callable[[], T_Result], _unknown_member: typing.Callable[[str], T_Result]) -> T_Result:
        if self is OccurrenceInformationCodeQualifier.CBH:
            return cbh()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import AuthGetTokenResponse, InvalidContentTypeErrorType, TooManyRequestsErrorType
from .errors import InvalidContentTypeError, TooManyRequestsError

__all__ = [
    "AuthGetTokenResponse",
    "InvalidContentTypeError",
    "InvalidContentTypeErrorType",
    "TooManyRequestsError",
    "TooManyRequestsErrorType",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .claim_submission_record_create import ClaimSubmissionRecordCreate
from .claim_submission_record_create_optional import ClaimSubmissionRecordCreateOptional
from .external_claim_submission_create import ExternalClaimSubmissionCreate
from .external_claim_submission_create_optional import ExternalClaimSubmissionCreateOptional

__all__ = [
    "ClaimSubmissionRecordCreate",
    "ClaimSubmissionRecordCreateOptional",
    "ExternalClaimSubmissionCreate",
    "ExternalClaimSubmissionCreateOptional",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EncounterSortOptions(str, enum.Enum):
    CREATED_AT_ASC = "created_at:asc"
    CREATED_AT_DESC = "created_at:desc"
    DATE_OF_SERVICE_ASC = "date_of_service:asc"
    DATE_OF_SERVICE_DESC = "date_of_service:desc"
    _UNKNOWN = "__ENCOUNTERSORTOPTIONS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EncounterSortOptions":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        created_at_asc: typing.Callable[[], T_Result],
        created_at_desc: typing.Callable[[], T_Result],
        date_of_service_asc: typing.Callable[[], T_Result],
        date_of_service_desc: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EncounterSortOptions.CREATED_AT_ASC:
            return created_at_asc()
        if self is EncounterSortOptions.CREATED_AT_DESC:
            return created_at_desc()
        if self is EncounterSortOptions.DATE_OF_SERVICE_ASC:
            return date_of_service_asc()
        if self is EncounterSortOptions.DATE_OF_SERVICE_DESC:
            return date_of_service_desc()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from .......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .......core.request_options import RequestOptions
from ....common.types.filter_query_string import FilterQueryString
from ....common.types.page_token import PageToken
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.batch_eligibility_response import BatchEligibilityResponse
from .types.eligibility_check_page import EligibilityCheckPage
from .types.eligibility_recommendation import EligibilityRecommendation
from .types.eligibility_request import EligibilityRequest
from .types.eligibility_response import EligibilityResponse
from .types.payer_search_response import PayerSearchResponse
from .types.post_eligibility_recommendation_request import PostEligibilityRecommendationRequest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def post(
        self, *, request: EligibilityRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> EligibilityResponse:
        """
        Sends real-time eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : EligibilityRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityResponse

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.coverages.resources.v_1 import (
            MemberInfo,
        )
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRequest,
            IndividualProvider,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.post(
            request=EligibilityRequest(
                payer_id="payer_id",
                provider=IndividualProvider(
                    npi="npi",
                ),
                subscriber=MemberInfo(
                    first_name="first_name",
                    last_name="last_name",
                ),
            ),
        )
        """
        _response = self._raw_client.post(request=request, request_options=request_options)
        return _response.data

    def batch(
        self, *, request: typing.Sequence[EligibilityRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> BatchEligibilityResponse:
        """
        Sends a batch of eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : typing.Sequence[EligibilityRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchEligibilityResponse

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.coverages.resources.v_1 import (
            MemberInfo,
        )
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRequest,
            IndividualProvider,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.batch(
            request=[
                EligibilityRequest(
                    payer_id="payer_id",
                    provider=IndividualProvider(
                        npi="npi",
                    ),
                    subscriber=MemberInfo(
                        first_name="first_name",
                        last_name="last_name",
                    ),
                ),
                EligibilityRequest(
                    payer_id="payer_id",
                    provider=IndividualProvider(
                        npi="npi",
                    ),
                    subscriber=MemberInfo(
                        first_name="first_name",
                        last_name="last_name",
                    ),
                ),
            ],
        )
        """
        _response = self._raw_client.batch(request=request, request_options=request_options)
        return _response.data

    def poll_batch(
        self,
        batch_id: str,
        *,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EligibilityCheckPage:
        """
        Polls the status of a batch eligibility check.

        Parameters
        ----------
        batch_id : str

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityCheckPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.poll_batch(
            batch_id="batch_id",
        )
        """
        _response = self._raw_client.poll_batch(batch_id, page_token=page_token, request_options=request_options)
        return _response.data

    def payer_search(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayerSearchResponse:
        """
        Searches for payers that match the query parameters.

        Parameters
        ----------
        page_size : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        query : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayerSearchResponse

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.payer_search()
        """
        _response = self._raw_client.payer_search(
            page_size=page_size, page_token=page_token, query=query, request_options=request_options
        )
        return _response.data

    def recommendation(
        self,
        *,
        filters: typing.Optional[FilterQueryString] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[EligibilityRecommendation]:
        """
        Gets recommendation for eligibility checks based on the request.

        Parameters
        ----------
        filters : typing.Optional[FilterQueryString]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[EligibilityRecommendation]

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.recommendation()
        """
        _response = self._raw_client.recommendation(filters=filters, request_options=request_options)
        return _response.data

    def create_recommendation(
        self, *, request: PostEligibilityRecommendationRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> EligibilityRecommendation:
        """
        Create an eligibiilty recommendation based on the request.

        Parameters
        ----------
        request : PostEligibilityRecommendationRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityRecommendation

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRecommendationPatientInfo,
            EligibilityRecommendationPayload_MedicareAdvantage,
            MedicareAdvantageRecommendationPayload,
            PostEligibilityRecommendationRequest,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.eligibility_checks.v_1.create_recommendation(
            request=PostEligibilityRecommendationRequest(
                eligibility_check_id="eligibility_check_id",
                patient=EligibilityRecommendationPatientInfo(),
                recommendation=EligibilityRecommendationPayload_MedicareAdvantage(
                    payload=MedicareAdvantageRecommendationPayload(),
                ),
            ),
        )
        """
        _response = self._raw_client.create_recommendation(request=request, request_options=request_options)
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def post(
        self, *, request: EligibilityRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> EligibilityResponse:
        """
        Sends real-time eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : EligibilityRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityResponse

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.coverages.resources.v_1 import (
            MemberInfo,
        )
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRequest,
            IndividualProvider,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.post(
                request=EligibilityRequest(
                    payer_id="payer_id",
                    provider=IndividualProvider(
                        npi="npi",
                    ),
                    subscriber=MemberInfo(
                        first_name="first_name",
                        last_name="last_name",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.post(request=request, request_options=request_options)
        return _response.data

    async def batch(
        self, *, request: typing.Sequence[EligibilityRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> BatchEligibilityResponse:
        """
        Sends a batch of eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : typing.Sequence[EligibilityRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        BatchEligibilityResponse

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.coverages.resources.v_1 import (
            MemberInfo,
        )
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRequest,
            IndividualProvider,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.batch(
                request=[
                    EligibilityRequest(
                        payer_id="payer_id",
                        provider=IndividualProvider(
                            npi="npi",
                        ),
                        subscriber=MemberInfo(
                            first_name="first_name",
                            last_name="last_name",
                        ),
                    ),
                    EligibilityRequest(
                        payer_id="payer_id",
                        provider=IndividualProvider(
                            npi="npi",
                        ),
                        subscriber=MemberInfo(
                            first_name="first_name",
                            last_name="last_name",
                        ),
                    ),
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.batch(request=request, request_options=request_options)
        return _response.data

    async def poll_batch(
        self,
        batch_id: str,
        *,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EligibilityCheckPage:
        """
        Polls the status of a batch eligibility check.

        Parameters
        ----------
        batch_id : str

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityCheckPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.poll_batch(
                batch_id="batch_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.poll_batch(batch_id, page_token=page_token, request_options=request_options)
        return _response.data

    async def payer_search(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayerSearchResponse:
        """
        Searches for payers that match the query parameters.

        Parameters
        ----------
        page_size : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        query : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayerSearchResponse

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.payer_search()


        asyncio.run(main())
        """
        _response = await self._raw_client.payer_search(
            page_size=page_size, page_token=page_token, query=query, request_options=request_options
        )
        return _response.data

    async def recommendation(
        self,
        *,
        filters: typing.Optional[FilterQueryString] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[EligibilityRecommendation]:
        """
        Gets recommendation for eligibility checks based on the request.

        Parameters
        ----------
        filters : typing.Optional[FilterQueryString]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[EligibilityRecommendation]

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.recommendation()


        asyncio.run(main())
        """
        _response = await self._raw_client.recommendation(filters=filters, request_options=request_options)
        return _response.data

    async def create_recommendation(
        self, *, request: PostEligibilityRecommendationRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> EligibilityRecommendation:
        """
        Create an eligibiilty recommendation based on the request.

        Parameters
        ----------
        request : PostEligibilityRecommendationRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EligibilityRecommendation

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.eligibility_checks.resources.v_1 import (
            EligibilityRecommendationPatientInfo,
            EligibilityRecommendationPayload_MedicareAdvantage,
            MedicareAdvantageRecommendationPayload,
            PostEligibilityRecommendationRequest,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.eligibility_checks.v_1.create_recommendation(
                request=PostEligibilityRecommendationRequest(
                    eligibility_check_id="eligibility_check_id",
                    patient=EligibilityRecommendationPatientInfo(),
                    recommendation=EligibilityRecommendationPayload_MedicareAdvantage(
                        payload=MedicareAdvantageRecommendationPayload(),
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_recommendation(request=request, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .denial_reason_content import DenialReasonContent
from .drug_identification import DrugIdentification
from .drug_identification_optional import DrugIdentificationOptional
from .measurement_unit_code import MeasurementUnitCode
from .service_id_qualifier import ServiceIdQualifier
from .service_line import ServiceLine
from .service_line_adjustment import ServiceLineAdjustment
from .service_line_create import ServiceLineCreate
from .service_line_create_base import ServiceLineCreateBase
from .service_line_create_base_base import ServiceLineCreateBaseBase
from .service_line_create_optional import ServiceLineCreateOptional
from .service_line_create_standalone import ServiceLineCreateStandalone
from .service_line_create_standalone_base import ServiceLineCreateStandaloneBase
from .service_line_create_standalone_base_base import ServiceLineCreateStandaloneBaseBase
from .service_line_denial_reason import ServiceLineDenialReason
from .service_line_era_data import ServiceLineEraData
from .service_line_update import ServiceLineUpdate
from .service_line_update_base import ServiceLineUpdateBase
from .test_result import TestResult
from .test_result_optional import TestResultOptional
from .test_result_type import TestResultType
from .universal_service_line_create import UniversalServiceLineCreate
from .universal_service_line_create_standalone import UniversalServiceLineCreateStandalone
from .universal_service_line_update import UniversalServiceLineUpdate

__all__ = [
    "DenialReasonContent",
    "DrugIdentification",
    "DrugIdentificationOptional",
    "MeasurementUnitCode",
    "ServiceIdQualifier",
    "ServiceLine",
    "ServiceLineAdjustment",
    "ServiceLineCreate",
    "ServiceLineCreateBase",
    "ServiceLineCreateBaseBase",
    "ServiceLineCreateOptional",
    "ServiceLineCreateStandalone",
    "ServiceLineCreateStandaloneBase",
    "ServiceLineCreateStandaloneBaseBase",
    "ServiceLineDenialReason",
    "ServiceLineEraData",
    "ServiceLineUpdate",
    "ServiceLineUpdateBase",
    "TestResult",
    "TestResultOptional",
    "TestResultType",
    "UniversalServiceLineCreate",
    "UniversalServiceLineCreateStandalone",
    "UniversalServiceLineUpdate",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class NonInsurancePayerPaymentSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    PAYMENT_TIMESTAMP = "payment_timestamp"
    _UNKNOWN = "__NONINSURANCEPAYERPAYMENTSORTFIELD_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "NonInsurancePayerPaymentSortField":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        amount_cents: typing.Callable[[], T_Result],
        payment_timestamp: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is NonInsurancePayerPaymentSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is NonInsurancePayerPaymentSortField.PAYMENT_TIMESTAMP:
            return payment_timestamp()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ClaimSubmissionRecordCreate,
    ClaimSubmissionRecordCreateOptional,
    ExternalClaimSubmissionCreate,
    ExternalClaimSubmissionCreateOptional,
)

__all__ = [
    "ClaimSubmissionRecordCreate",
    "ClaimSubmissionRecordCreateOptional",
    "ExternalClaimSubmissionCreate",
    "ExternalClaimSubmissionCreateOptional",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .authorization import Authorization
from .authorization_unit import AuthorizationUnit
from .contact import Contact
from .do_not_invoice_reason import DoNotInvoiceReason
from .external_provenance import ExternalProvenance
from .filing_order import FilingOrder
from .guarantor import Guarantor
from .inferred_patient_metadata import InferredPatientMetadata
from .marital_status import MaritalStatus
from .mutable_patient import MutablePatient
from .mutable_patient_with_mrn import MutablePatientWithMrn
from .origination_detail import OriginationDetail
from .patient import Patient
from .patient_page import PatientPage
from .patient_sort_field import PatientSortField
from .referral import Referral
from .referral_source import ReferralSource
from .referral_type import ReferralType
from .referral_unit import ReferralUnit
from .specialization_category import SpecializationCategory

__all__ = [
    "Authorization",
    "AuthorizationUnit",
    "Contact",
    "DoNotInvoiceReason",
    "ExternalProvenance",
    "FilingOrder",
    "Guarantor",
    "InferredPatientMetadata",
    "MaritalStatus",
    "MutablePatient",
    "MutablePatientWithMrn",
    "OriginationDetail",
    "Patient",
    "PatientPage",
    "PatientSortField",
    "Referral",
    "ReferralSource",
    "ReferralType",
    "ReferralUnit",
    "SpecializationCategory",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_id import EventId


class Event(UniversalBaseModel):
    id: EventId
    created_at: dt.datetime
    timestamp: dt.datetime
    event_type: str
    schema_version: str
    payload: typing.Optional[typing.Any] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawExpectedNetworkStatusClient, RawExpectedNetworkStatusClient
from .resources.v_1.client import AsyncV1Client, V1Client
from .resources.v_2.client import AsyncV2Client, V2Client


class ExpectedNetworkStatusClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawExpectedNetworkStatusClient(client_wrapper=client_wrapper)
        self.v_1 = V1Client(client_wrapper=client_wrapper)

        self.v_2 = V2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawExpectedNetworkStatusClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExpectedNetworkStatusClient
        """
        return self._raw_client


class AsyncExpectedNetworkStatusClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawExpectedNetworkStatusClient(client_wrapper=client_wrapper)
        self.v_1 = AsyncV1Client(client_wrapper=client_wrapper)

        self.v_2 = AsyncV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExpectedNetworkStatusClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExpectedNetworkStatusClient
        """
        return self._raw_client



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    BatchEligibilityResponse,
    CoordinationOfBenefitsRecommendation,
    EligibilityCheck,
    EligibilityCheckError,
    EligibilityCheckErrorDetails,
    EligibilityCheckErrorSource,
    EligibilityCheckMetadata,
    EligibilityCheckPage,
    EligibilityCheckStatus,
    EligibilityRecommendation,
    EligibilityRecommendationPatientInfo,
    EligibilityRecommendationPayload,
    EligibilityRecommendationPayload_CoordinationOfBenefits,
    EligibilityRecommendationPayload_MedicareAdvantage,
    EligibilityRequest,
    EligibilityResponse,
    EligibilityStatus,
    Encounter,
    IndividualProvider,
    MedicareAdvantageRecommendation,
    MedicareAdvantageRecommendationPayload,
    OrganizationProvider,
    ParsedResponse,
    PayerSearchResponse,
    PostEligibilityRecommendationRequest,
    Provider,
    RequestCorrection,
    StediPayer,
    StediPayerItem,
)

__all__ = [
    "BatchEligibilityResponse",
    "CoordinationOfBenefitsRecommendation",
    "EligibilityCheck",
    "EligibilityCheckError",
    "EligibilityCheckErrorDetails",
    "EligibilityCheckErrorSource",
    "EligibilityCheckMetadata",
    "EligibilityCheckPage",
    "EligibilityCheckStatus",
    "EligibilityRecommendation",
    "EligibilityRecommendationPatientInfo",
    "EligibilityRecommendationPayload",
    "EligibilityRecommendationPayload_CoordinationOfBenefits",
    "EligibilityRecommendationPayload_MedicareAdvantage",
    "EligibilityRequest",
    "EligibilityResponse",
    "EligibilityStatus",
    "Encounter",
    "IndividualProvider",
    "MedicareAdvantageRecommendation",
    "MedicareAdvantageRecommendationPayload",
    "OrganizationProvider",
    "ParsedResponse",
    "PayerSearchResponse",
    "PostEligibilityRecommendationRequest",
    "Provider",
    "RequestCorrection",
    "StediPayer",
    "StediPayerItem",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .......core.api_error import ApiError
from .......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .......core.http_response import AsyncHttpResponse, HttpResponse
from .......core.jsonable_encoder import jsonable_encoder
from .......core.pydantic_utilities import parse_obj_as
from .......core.request_options import RequestOptions
from ....common.types.filter_query_string import FilterQueryString
from ....common.types.page_token import PageToken
from .types.batch_eligibility_response import BatchEligibilityResponse
from .types.eligibility_check_page import EligibilityCheckPage
from .types.eligibility_recommendation import EligibilityRecommendation
from .types.eligibility_request import EligibilityRequest
from .types.eligibility_response import EligibilityResponse
from .types.payer_search_response import PayerSearchResponse
from .types.post_eligibility_recommendation_request import PostEligibilityRecommendationRequest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def post(
        self, *, request: EligibilityRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EligibilityResponse]:
        """
        Sends real-time eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : EligibilityRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EligibilityResponse]
        """
        _response = self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityResponse,
                parse_obj_as(
                    type_=EligibilityResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def batch(
        self, *, request: typing.Sequence[EligibilityRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[BatchEligibilityResponse]:
        """
        Sends a batch of eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : typing.Sequence[EligibilityRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[BatchEligibilityResponse]
        """
        _response = self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/batch",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                BatchEligibilityResponse,
                parse_obj_as(
                    type_=BatchEligibilityResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def poll_batch(
        self,
        batch_id: str,
        *,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EligibilityCheckPage]:
        """
        Polls the status of a batch eligibility check.

        Parameters
        ----------
        batch_id : str

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EligibilityCheckPage]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"eligibility-checks/v1/batch/{jsonable_encoder(batch_id)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityCheckPage,
                parse_obj_as(
                    type_=EligibilityCheckPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def payer_search(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[PayerSearchResponse]:
        """
        Searches for payers that match the query parameters.

        Parameters
        ----------
        page_size : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        query : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[PayerSearchResponse]
        """
        _response = self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/payer/search",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "page_size": page_size,
                "page_token": page_token,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                PayerSearchResponse,
                parse_obj_as(
                    type_=PayerSearchResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def recommendation(
        self,
        *,
        filters: typing.Optional[FilterQueryString] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[EligibilityRecommendation]]:
        """
        Gets recommendation for eligibility checks based on the request.

        Parameters
        ----------
        filters : typing.Optional[FilterQueryString]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[EligibilityRecommendation]]
        """
        _response = self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/recommendation",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "filters": filters,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[EligibilityRecommendation],
                parse_obj_as(
                    type_=typing.List[EligibilityRecommendation],  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_recommendation(
        self, *, request: PostEligibilityRecommendationRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EligibilityRecommendation]:
        """
        Create an eligibiilty recommendation based on the request.

        Parameters
        ----------
        request : PostEligibilityRecommendationRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EligibilityRecommendation]
        """
        _response = self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/recommendation",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityRecommendation,
                parse_obj_as(
                    type_=EligibilityRecommendation,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def post(
        self, *, request: EligibilityRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EligibilityResponse]:
        """
        Sends real-time eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : EligibilityRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EligibilityResponse]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityResponse,
                parse_obj_as(
                    type_=EligibilityResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def batch(
        self, *, request: typing.Sequence[EligibilityRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[BatchEligibilityResponse]:
        """
        Sends a batch of eligibility checks to payers through Stedi.

        Parameters
        ----------
        request : typing.Sequence[EligibilityRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[BatchEligibilityResponse]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/batch",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                BatchEligibilityResponse,
                parse_obj_as(
                    type_=BatchEligibilityResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def poll_batch(
        self,
        batch_id: str,
        *,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EligibilityCheckPage]:
        """
        Polls the status of a batch eligibility check.

        Parameters
        ----------
        batch_id : str

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EligibilityCheckPage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"eligibility-checks/v1/batch/{jsonable_encoder(batch_id)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityCheckPage,
                parse_obj_as(
                    type_=EligibilityCheckPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def payer_search(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[PayerSearchResponse]:
        """
        Searches for payers that match the query parameters.

        Parameters
        ----------
        page_size : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        query : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[PayerSearchResponse]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/payer/search",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "page_size": page_size,
                "page_token": page_token,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                PayerSearchResponse,
                parse_obj_as(
                    type_=PayerSearchResponse,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def recommendation(
        self,
        *,
        filters: typing.Optional[FilterQueryString] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[EligibilityRecommendation]]:
        """
        Gets recommendation for eligibility checks based on the request.

        Parameters
        ----------
        filters : typing.Optional[FilterQueryString]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[EligibilityRecommendation]]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/recommendation",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            params={
                "filters": filters,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[EligibilityRecommendation],
                parse_obj_as(
                    type_=typing.List[EligibilityRecommendation],  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_recommendation(
        self, *, request: PostEligibilityRecommendationRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EligibilityRecommendation]:
        """
        Create an eligibiilty recommendation based on the request.

        Parameters
        ----------
        request : PostEligibilityRecommendationRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EligibilityRecommendation]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "eligibility-checks/v1/recommendation",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                EligibilityRecommendation,
                parse_obj_as(
                    type_=EligibilityRecommendation,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .appointment_list_item import AppointmentListItem
from .appointment_list_page import AppointmentListPage
from .patient_list_item import PatientListItem
from .patient_list_page import PatientListPage
from .sort_field_string import SortFieldString

__all__ = ["AppointmentListItem", "AppointmentListPage", "PatientListItem", "PatientListPage", "SortFieldString"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .contract import Contract
from .contract_base import ContractBase
from .contract_create import ContractCreate
from .contract_create_union import (
    ContractCreateUnion,
    ContractCreateUnion_Institutional,
    ContractCreateUnion_Professional,
)
from .contract_id import ContractId
from .contract_service_facility import ContractServiceFacility
from .contract_service_facility_base import ContractServiceFacilityBase
from .contract_service_facility_id import ContractServiceFacilityId
from .contract_type import ContractType
from .contract_union import ContractUnion, ContractUnion_Institutional, ContractUnion_Professional
from .contract_update import ContractUpdate
from .contract_update_union import (
    ContractUpdateUnion,
    ContractUpdateUnion_Institutional,
    ContractUpdateUnion_Professional,
)
from .contract_with_providers_union import (
    ContractWithProvidersUnion,
    ContractWithProvidersUnion_Institutional,
    ContractWithProvidersUnion_Professional,
)
from .contracting_provider_id import ContractingProviderId
from .contracts_page import ContractsPage
from .institutional_contract import InstitutionalContract
from .institutional_contract_create import InstitutionalContractCreate
from .institutional_contract_update import InstitutionalContractUpdate
from .professional_contract import ProfessionalContract
from .professional_contract_create import ProfessionalContractCreate
from .professional_contract_update import ProfessionalContractUpdate
from .rendering_providerid import RenderingProviderid

__all__ = [
    "Contract",
    "ContractBase",
    "ContractCreate",
    "ContractCreateUnion",
    "ContractCreateUnion_Institutional",
    "ContractCreateUnion_Professional",
    "ContractId",
    "ContractServiceFacility",
    "ContractServiceFacilityBase",
    "ContractServiceFacilityId",
    "ContractType",
    "ContractUnion",
    "ContractUnion_Institutional",
    "ContractUnion_Professional",
    "ContractUpdate",
    "ContractUpdateUnion",
    "ContractUpdateUnion_Institutional",
    "ContractUpdateUnion_Professional",
    "ContractWithProvidersUnion",
    "ContractWithProvidersUnion_Institutional",
    "ContractWithProvidersUnion_Professional",
    "ContractingProviderId",
    "ContractsPage",
    "InstitutionalContract",
    "InstitutionalContractCreate",
    "InstitutionalContractUpdate",
    "ProfessionalContract",
    "ProfessionalContractCreate",
    "ProfessionalContractUpdate",
    "RenderingProviderid",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from .....commons.types.error_message import ErrorMessage


class ExportFilesUnavailableError(ApiError):
    def __init__(self, body: ErrorMessage, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=503, headers=headers, body=body)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .event import Event
from .event_id import EventId
from .event_scan_page import EventScanPage

__all__ = ["Event", "EventId", "EventScanPage"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .invalid_content_type_error import InvalidContentTypeError
from .too_many_requests_error import TooManyRequestsError

__all__ = ["InvalidContentTypeError", "TooManyRequestsError"]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .medicare_advantage_recommendation_payload import MedicareAdvantageRecommendationPayload


class EligibilityRecommendationPayload_MedicareAdvantage(UniversalBaseModel):
    type: typing.Literal["MEDICARE_ADVANTAGE"] = "MEDICARE_ADVANTAGE"
    payload: MedicareAdvantageRecommendationPayload

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EligibilityRecommendationPayload_CoordinationOfBenefits(UniversalBaseModel):
    type: typing.Literal["COORDINATION_OF_BENEFITS"] = "COORDINATION_OF_BENEFITS"
    payload: typing.Optional[typing.Any] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


EligibilityRecommendationPayload = typing.Union[
    EligibilityRecommendationPayload_MedicareAdvantage, EligibilityRecommendationPayload_CoordinationOfBenefits
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .universal_encounter_create import UniversalEncounterCreate
from .universal_encounter_create_base import UniversalEncounterCreateBase
from .universal_encounter_create_from_pre_encounter import UniversalEncounterCreateFromPreEncounter
from .universal_encounter_create_from_pre_encounter_base import UniversalEncounterCreateFromPreEncounterBase
from .universal_encounter_update import UniversalEncounterUpdate
from .universal_encounter_update_base import UniversalEncounterUpdateBase

__all__ = [
    "UniversalEncounterCreate",
    "UniversalEncounterCreateBase",
    "UniversalEncounterCreateFromPreEncounter",
    "UniversalEncounterCreateFromPreEncounterBase",
    "UniversalEncounterUpdate",
    "UniversalEncounterUpdateBase",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    Carc,
    ClaimAdjustmentReasonCode,
    PatientDischargeStatusCode,
    PointOfOriginForAdmissionOrVisitCode,
    Rarc,
    RemittanceAdviceRemarkCode,
    TypeOfAdmissionOrVisitCode,
    TypeOfBillComposite,
    TypeOfBillCompositeBase,
    TypeOfBillCompositeUpdate,
    TypeOfBillCompositeUpdate_CompositeCodes,
    TypeOfBillCompositeUpdate_RawCode,
    TypeOfBillFrequencyCode,
    TypeOfCareCode,
    TypeOfFacilityCode,
)

__all__ = [
    "Carc",
    "ClaimAdjustmentReasonCode",
    "PatientDischargeStatusCode",
    "PointOfOriginForAdmissionOrVisitCode",
    "Rarc",
    "RemittanceAdviceRemarkCode",
    "TypeOfAdmissionOrVisitCode",
    "TypeOfBillComposite",
    "TypeOfBillCompositeBase",
    "TypeOfBillCompositeUpdate",
    "TypeOfBillCompositeUpdate_CompositeCodes",
    "TypeOfBillCompositeUpdate_RawCode",
    "TypeOfBillFrequencyCode",
    "TypeOfCareCode",
    "TypeOfFacilityCode",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .attachment_inclusion import AttachmentInclusion
from .create_supplemental_information_request import CreateSupplementalInformationRequest
from .supplemental_information import SupplementalInformation
from .supplemental_information_id import SupplementalInformationId
from .update_supplemental_information_request import UpdateSupplementalInformationRequest

__all__ = [
    "AttachmentInclusion",
    "CreateSupplementalInformationRequest",
    "SupplementalInformation",
    "SupplementalInformationId",
    "UpdateSupplementalInformationRequest",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.street_address_short_zip import StreetAddressShortZip


class GuarantorBase(UniversalBaseModel):
    first_name: str
    last_name: str
    external_id: str
    date_of_birth: typing.Optional[dt.date] = None
    address: StreetAddressShortZip

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    Contract,
    ContractBase,
    ContractCreate,
    ContractCreateUnion,
    ContractCreateUnion_Institutional,
    ContractCreateUnion_Professional,
    ContractId,
    ContractServiceFacility,
    ContractServiceFacilityBase,
    ContractServiceFacilityId,
    ContractType,
    ContractUnion,
    ContractUnion_Institutional,
    ContractUnion_Professional,
    ContractUpdate,
    ContractUpdateUnion,
    ContractUpdateUnion_Institutional,
    ContractUpdateUnion_Professional,
    ContractWithProvidersUnion,
    ContractWithProvidersUnion_Institutional,
    ContractWithProvidersUnion_Professional,
    ContractingProviderId,
    ContractsPage,
    InstitutionalContract,
    InstitutionalContractCreate,
    InstitutionalContractUpdate,
    ProfessionalContract,
    ProfessionalContractCreate,
    ProfessionalContractUpdate,
    RenderingProviderid,
)

__all__ = [
    "Contract",
    "ContractBase",
    "ContractCreate",
    "ContractCreateUnion",
    "ContractCreateUnion_Institutional",
    "ContractCreateUnion_Professional",
    "ContractId",
    "ContractServiceFacility",
    "ContractServiceFacilityBase",
    "ContractServiceFacilityId",
    "ContractType",
    "ContractUnion",
    "ContractUnion_Institutional",
    "ContractUnion_Professional",
    "ContractUpdate",
    "ContractUpdateUnion",
    "ContractUpdateUnion_Institutional",
    "ContractUpdateUnion_Professional",
    "ContractWithProvidersUnion",
    "ContractWithProvidersUnion_Institutional",
    "ContractWithProvidersUnion_Professional",
    "ContractingProviderId",
    "ContractsPage",
    "InstitutionalContract",
    "InstitutionalContractCreate",
    "InstitutionalContractUpdate",
    "ProfessionalContract",
    "ProfessionalContractCreate",
    "ProfessionalContractUpdate",
    "RenderingProviderid",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .base_credentialing_span import BaseCredentialingSpan
from .credentialing_span_status import CredentialingSpanStatus
from .facility_credentialing_span import FacilityCredentialingSpan
from .facility_credentialing_span_id import FacilityCredentialingSpanId
from .facility_credentialing_span_page import FacilityCredentialingSpanPage
from .provider_credentialing_span import ProviderCredentialingSpan
from .provider_credentialing_span_id import ProviderCredentialingSpanId
from .provider_credentialing_span_page import ProviderCredentialingSpanPage

__all__ = [
    "BaseCredentialingSpan",
    "CredentialingSpanStatus",
    "FacilityCredentialingSpan",
    "FacilityCredentialingSpanId",
    "FacilityCredentialingSpanPage",
    "ProviderCredentialingSpan",
    "ProviderCredentialingSpanId",
    "ProviderCredentialingSpanPage",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2
from .....common.types.base_model import BaseModel
from .....common.types.note_id import NoteId
from .mutable_note import MutableNote


class Note(BaseModel, MutableNote):
    """
    A Note object with immutable server-owned properties.
    """

    id: NoteId
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
